package Task::Trepan;

use strict;
use vars qw( $VERSION );
BEGIN {
    $VERSION = '1.1';
}

'Is that all there is to it?';
